@@ -1,3 +1,4 @@
+from datetime import datetime
 from pprint import pformat
 from typing import Any, List, Iterable, Optional
 
@@ -6,6 +7,7 @@ from jinja2 import Template as J2Template
 from retrying import retry
 from tqdm import tqdm
 from zeep.helpers import serialize_object
+import pytz
 
 from .config import config, VERBOSE1, VERBOSE2
 from .exceptions import ResourceNotActive, ResourceNotFound
@@ -13,7 +15,7 @@ from .operations import Advertiser, AdUnit, Placement, TargetingKey, TargetingVa
      CreativeBanner, CreativeVideo, Order, CurrentNetwork, CurrentUser, LineItem, LICA
 from .prebid import PrebidBidder
 from .template import render_cfg, render_src
-from .utils import format_long_list, ichunk, read_package_file
+from .utils import format_long_list, ichunk
 
 logger = config.getLogger(__name__)
 
@@ -149,7 +151,7 @@ class GAMLineItems:
     def line_items(self) -> List[dict]:
         if self._line_items is None:
             recs = []
-            src = read_package_file('line_item_template.yml')
+            src = config.template_src()
             for i_, cpm in enumerate(self.cpms):
                 li_cfg = render_cfg('line_item', self.bidder, cpm=cpm, media_type=self.media_type)
                 if (i_ == 0) or (i_ == len(self.cpms) - 1) or config.isLoggingEnabled(VERBOSE2):
